@@ -19,7 +19,6 @@
  */
 
 #include <oobs/oobs.h>
-#include <libgnome/gnome-init.h>
 #include <string.h>
 #include "network-locations.h"
 #include <sys/types.h>
@@ -127,7 +126,8 @@ PropType plip_properties[] = {
   { "active", TYPE_BOOLEAN },
   { "configured", TYPE_BOOLEAN },
   { "address", TYPE_STRING },
-  { "remote-address", TYPE_STRING }
+  { "remote-address", TYPE_STRING },
+  { NULL }
 };
 
 
@@ -158,6 +158,8 @@ gst_network_locations_class_init (GstNetworkLocationsClass *class)
 			    sizeof (GstNetworkLocationsPrivate));
 }
 
+#define GNOME_DOT_GNOME ".gnome2/"
+
 static gchar*
 create_dot_dir ()
 {
@@ -770,11 +772,9 @@ concatenate_aliases (OobsStaticHost *static_host)
       elem = elem->next;
     }
 
-  g_list_foreach (list, (GFunc) g_free, NULL);
-  g_list_free (list);
-
   s = str->str;
   g_string_free (str, FALSE);
+  g_list_free (list);
 
   return s;
 }
@@ -819,17 +819,18 @@ save_hosts_config (OobsHostsConfig *config,
 {
   GList *list;
   gchar **arr;
+  const gchar *str;
 
-  g_key_file_set_string (key_file, "general", "hostname",
-			 oobs_hosts_config_get_hostname (config));
-  g_key_file_set_string (key_file, "general", "domainname",
-			 oobs_hosts_config_get_domainname (config));
+  str = oobs_hosts_config_get_hostname (config);
+  g_key_file_set_string (key_file, "general", "hostname", (str) ? str : "");
+
+  str = oobs_hosts_config_get_domainname (config);
+  g_key_file_set_string (key_file, "general", "domainname", (str) ? str : "");
 
   list = oobs_hosts_config_get_dns_servers (config);
   arr = list_to_array (list);
   g_key_file_set_string_list (key_file, "general", "dns-servers",
 			      (const gchar**) arr, g_strv_length (arr));
-  g_list_foreach (list, (GFunc) g_free, NULL);
   g_list_free (list);
   g_strfreev (arr);
 
@@ -837,7 +838,6 @@ save_hosts_config (OobsHostsConfig *config,
   arr = list_to_array (list);
   g_key_file_set_string_list (key_file, "general", "search-domains",
 			      (const gchar**) arr, g_strv_length (arr));
-  g_list_foreach (list, (GFunc) g_free, NULL);
   g_list_free (list);
   g_strfreev (arr);
 
